package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.EmsTag;

import java.util.List;

/**
 * 标签分类Service接口
 *
 * @author ruoyi
 * @date 2024-07-31
 */
public interface IEmsTagService {
    /**
     * 查询标签分类
     *
     * @param id 标签分类主键
     * @return 标签分类
     */
    EmsTag selectEmsTagById(Long id);

    /**
     * 查询标签分类列表
     *
     * @param emsTag 标签分类
     * @return 标签分类集合
     */
    List<EmsTag> selectEmsTagList(EmsTag emsTag);

    /**
     * 新增标签分类
     *
     * @param emsTag 标签分类
     * @return 结果
     */
    int insertEmsTag(EmsTag emsTag);

    /**
     * 修改标签分类
     *
     * @param emsTag 标签分类
     * @return 结果
     */
    int updateEmsTag(EmsTag emsTag);

    /**
     * 批量删除标签分类
     *
     * @param ids 需要删除的标签分类主键集合
     * @return 结果
     */
    int deleteEmsTagByIds(Long[] ids);

    /**
     * 删除标签分类信息
     *
     * @param id 标签分类主键
     * @return 结果
     */
    int deleteEmsTagById(Long id);
}
