package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.EmsTag;
import com.ruoyi.ems.service.IEmsTagService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 标签分类Controller
 * 
 * @author ruoyi
 * @date 2024-08-16
 */
@RestController
@RequestMapping("/ems/tag")
@Api(value = "EmsTagController", description = "标签管理管理")
public class EmsTagController extends BaseController
{
    @Autowired
    private IEmsTagService emsTagService;

    /**
     * 查询标签分类列表
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsTag emsTag)
    {
        startPage();
        List<EmsTag> list = emsTagService.selectEmsTagList(emsTag);
        return getDataTable(list);
    }

    /**
     * 导出标签分类列表
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:export')")
    @Log(title = "标签分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsTag dimEmsTag)
    {
        List<EmsTag> list = emsTagService.selectEmsTagList(dimEmsTag);
        ExcelUtil<EmsTag> util = new ExcelUtil<EmsTag>(EmsTag.class);
        util.exportExcel(response, list, "标签分类数据");
    }

    /**
     * 获取标签分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(emsTagService.selectEmsTagById(id));
    }

    /**
     * 新增标签分类
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:add')")
    @Log(title = "标签分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsTag dimEmsTag)
    {
        return toAjax(emsTagService.insertEmsTag(dimEmsTag));
    }

    /**
     * 修改标签分类
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:edit')")
    @Log(title = "标签分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsTag dimEmsTag)
    {

        return toAjax(emsTagService.updateEmsTag(dimEmsTag));
    }

    /**
     * 删除标签分类
     */
    @PreAuthorize("@ss.hasPermi('ems:tag:remove')")
    @Log(title = "标签分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(emsTagService.deleteEmsTagByIds(ids));
    }
}
